@@ -250,7 +250,9 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
            } else {
              x@.Data <- aperm(x, c(1,3,2,4))
            }
-           y@.Data <- aperm(y, c(1,3,2))
+           if (!missing(y)) {
+             y@.Data <- aperm(y, c(1,3,2))
+           }
            aspect <- x@pixdim[4] / x@pixdim[2]
          },
          "sagittal" = {
@@ -259,12 +261,17 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
            } else {
              x@.Data <- aperm(x, c(2,3,1,4))
            }
-           y@.Data <- aperm(y, c(2,3,1))
+           if (!missing(y)) {
+             y@.Data <- aperm(y, c(2,3,1))
+           }
            aspect <- x@pixdim[4] / x@pixdim[3]
          },
          stop(paste("Orthogonal plane", plane[1], "is not valid.")))
   ## both volumes must have the same dimension
-  if (! all(dim(x)[1:3] == dim(y)[1:3])) {
+  ndim = length(dim(x))
+  ndim_y = length(dim(y))
+  nd = min(ndim, ndim_y)
+  if (! all(dim(x)[1:nd] == dim(y)[1:nd])) {
     stop("dimensions of \"x\" and \"y\" must be equal")
   }
   
@@ -275,17 +282,20 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
                   "Likely set NA.x = FALSE."))
     }
   }  
-  if (NA.y) {
-    y[ y == 0 ] = NA
-    if (all(is.na(y))) {
-      stop(paste0("y has no non-zero values and NA.y = TRUE.  ", 
-                  "Either remove the overlay, or set NA.y = FALSE"))
+  if (!missing(y)) {
+    if (NA.y) {
+      y[ y == 0 ] = NA
+      if (all(is.na(y))) {
+        stop(paste0("y has no non-zero values and NA.y = TRUE.  ", 
+                    "Either remove the overlay, or set NA.y = FALSE"))
+      }
     }
   }
   ## set dimensions
   X <- nrow(x)
   Y <- ncol(x)
   Z <- nsli(x)
+  if (is.na(Z)) Z = 1
   W <- ntim(x)
   ## check dimensions
   if (X == 0 || Y == 0 || Z == 0) {
@@ -306,13 +316,15 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
                     length=length(col.x)-1),
                 max(x, zlim.x, na.rm=TRUE))
   ## check for z-limits in y; use internal by default
-  if (is.null(zlim.y)) {
-    zlim.y <- c(y@"cal_min", y@"cal_max")
-    if (any(!is.finite(zlim.y)) || diff(zlim.y) == 0) {
-      zlim.y <- c(y@"glmin", y@"glmax")
-    }
-    if (any(!is.finite(zlim.y)) || diff(zlim.y) == 0) {
-      zlim.y <- range(y, na.rm=TRUE)
+  if (!missing(y)) {
+    if (is.null(zlim.y)) {
+      zlim.y <- c(y@"cal_min", y@"cal_max")
+      if (any(!is.finite(zlim.y)) || diff(zlim.y) == 0) {
+        zlim.y <- c(y@"glmin", y@"glmax")
+      }
+      if (any(!is.finite(zlim.y)) || diff(zlim.y) == 0) {
+        zlim.y <- range(y, na.rm=TRUE)
+      }
     }
   }
   if (plot.type[1] == "multiple") {
@@ -326,12 +338,21 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
   }
   oldpar <- par(no.readonly=TRUE)
   par(mfrow=ceiling(rep(sqrt(lz),2)), oma=oma, mar=mar, bg=bg)
+  if (ndim == 2) {
+    x = array(x, dim = c(dim(x), 1))
+    z = 1
+    if (length(dim(y)) < 3) {
+      y = array(y, dim = c(dim(y), 1))
+    }
+  }  
   if (is.na(W)) { # three-dimensional array
     for (z in index) {
       graphics::image(1:X, 1:Y, x[,,z], col=col.x, breaks=breaks.x,
                       zlim=zlim.x, asp=aspect, axes=axes, xlab=xlab,
                       ylab=ylab, ...)
-      graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
+      if (!missing(y)) {
+        graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
+      }
     }
   } else { # four-dimensional array
     if (w < 1 || w > W) {
@@ -341,7 +362,9 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
       graphics::image(1:X, 1:Y, x[,,z,w], col=col.x, breaks=breaks.x,
                       zlim=zlim.x, asp=aspect, axes=axes, xlab=xlab,
                       ylab=ylab, ...)
-      graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
+      if (!missing(y)) {
+        graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
+      }
     }
   }
   par(oldpar)
@@ -352,6 +375,9 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
 setGeneric("overlay", function(x, y, ...) standardGeneric("overlay"))
 #' @export
 #' @rdname overlay-methods
+setMethod("overlay", signature(x="nifti", y="missing"), overlay.nifti)
+#' @export
+#' @rdname overlay-methods
 setMethod("overlay", signature(x="nifti", y="nifti"), overlay.nifti)
 #' @export
 #' @rdname overlay-methods
